Module hf_pull

Module hf_pull 

Hugging Face Hub download helper (hf download when the CLI is installed).

Functions

looks_like_hf_repo
True when path looks like a Hub repo id rather than a local file.
pull_hf_gguf
Download repo via hf download and return a local .gguf path.
resolve_model_path
If model is a Hub repo id, download and return the local GGUF path.